pycocoa.deprecated

Package pycocoa :: Module deprecated |
[frames] | no frames]

# Module deprecated

DEPRECATED classes, constants, functions, internals, modules, etc.

Version: 25.04.08

Classes
| BuiltInScreen DEPRECATED on 2025.03.16, use `Screens.BuiltIn`.
| Cache2 DEPRECATED on 2025.02.15, to be removed.
| DeepestScreen DEPRECATED on 2025.03.16, use `Screens.Deepest`.
| ExternalScreen DEPRECATED on 2025.03.16, use `Screens.External`.
| MainScreen DEPRECATED on 2025.03.16, use `Screens.Main`.
| module_property_RO DEPRECATED on 2025.02.09, use `Proxy1ce`.
| proxy_RO DEPRECATED on 2025.04.03, use `Proxy1ce`.

Functions
fontfamilies(*prefixes) DEPRECATED on 25.03.13, use `fontFamilies`. |
fontnamesof(family) DEPRECATED on 25.03.13, use `fontNamesOf`. |
fontsof(family, **size_weight) DEPRECATED on 25.03.13, use `fontsOf`. |
fontsof4(family) DEPRECATED on 25.03.13, use `fontsOf4`. |
get_classes(*prefixes) DEPRECATED on 25.03.30, use `get_classes2`. |
get_ivars(clas, *prefixes) DEPRECATED on 25.03.30, use `get_ivars4`. |
get_libPC() DEPRECATED on 25.02.25, use `Libs.PrintCore`. |
get_libs() DEPRECATED on 25.02.25, use `Libs`. |
get_methods(clas, *prefixes) DEPRECATED on 25.03.30, use `get_methods4`. |
get_properties(clas_or_proto, *prefixes) DEPRECATED on 25.03.30, use `get_properties4`. |
get_protocols(clas, *prefixes) DEPRECATED on 25.03.30, use `get_protocols2`. |
property2(inst, name) DEPRECATED on 25.02.16, to be removed. |
sortuples(iterable) DEPRECATED on 25.02.09, to be removed. |

Variables
| __all__ = `_ALL_LAZY.deprecated`
| libAppKit = `<_DeprecatedCDLL 'AppKit.framework/AppKit', handle`...``
| libCF = `<_DeprecatedCDLL 'CoreFoundation.framework/CoreFoundat`...``
| libCG = `<_DeprecatedCDLL 'CoreGraphics.framework/CoreGraphics'`...``
| libCT = `<_DeprecatedCDLL 'CoreText.framework/CoreText', handle`...``
| libFoundation = `<_DeprecatedCDLL 'Foundation.framework/Foundat`...``
| libobjc = `<_DeprecatedCDLL 'libobjc.dylib', handle 7ffc90b7ba0`...``
| libPC = `<_DeprecatedCDLL '/System/Library/Frameworks/Applicati`...``
| OBJC_ASSOCIATION_ASSIGN = `0`
| OBJC_ASSOCIATION_COPY = `771`
| OBJC_ASSOCIATION_COPY_NONATOMIC = `3`
| OBJC_ASSOCIATION_RETAIN = `769`
| OBJC_ASSOCIATION_RETAIN_NONATOMIC = `1`

Variables Details

  ### libAppKit Value:
      <_DeprecatedCDLL 'AppKit.framework/AppKit', handle 7ffc90b75d40 at 7fe
      84046ed90>

  ### libCF Value:
      <_DeprecatedCDLL 'CoreFoundation.framework/CoreFoundation', handle 7ff
      c90b78150 at 7fe84046ee10>

  ### libCG Value:
      <_DeprecatedCDLL 'CoreGraphics.framework/CoreGraphics', handle 7ffc90b
      72120 at 7fe84046ee50>

  ### libCT Value:
      <_DeprecatedCDLL 'CoreText.framework/CoreText', handle 7ffc90b761f8 at
       7fe84046ee90>

  ### libFoundation Value:
      <_DeprecatedCDLL 'Foundation.framework/Foundation', handle 7ffc90b7777
      0 at 7fe8501c8890>

  ### libobjc Value:
      <_DeprecatedCDLL 'libobjc.dylib', handle 7ffc90b7ba08 at 7fe8502884d0>

  ### libPC Value:
      <_DeprecatedCDLL '/System/Library/Frameworks/ApplicationServices.frame
      work/Frameworks/PrintCore.framework/PrintCore', handle 7ffc90b57cb0 at
       7fe850288550>